Function hyper_imp::ffi::hyper_clientconn_handshake
source · #[no_mangle]
pub extern "C" fn hyper_clientconn_handshake(
io: *mut hyper_io,
options: *mut hyper_clientconn_options
) -> *mut hyper_taskExpand description
Starts an HTTP client connection handshake using the provided IO transport and options.
Both the io and the options are consumed in this function call.
The returned hyper_task * must be polled with an executor until the
handshake completes, at which point the value can be taken.