Struct hyper_imp::ffi::hyper_clientconn
source · pub struct hyper_clientconn { /* private fields */ }Expand description
An HTTP client connection handle.
These are used to send a request on a single connection. It’s possible to send multiple requests on a single connection, such as when HTTP/1 keep-alive or HTTP/2 is used.